#!/usr/bin/env python

from distutils.core import setup, Extension
import subprocess
import re


PACKAGES = ['poppler-glib', 'pygobject-2.0', 'pycairo']

def pypoppler_version():
    re_version = re.compile('pypoppler_(\w+)_version,\ (\d+)')
    config = file('configure.ac', 'r')
    parts = ()
    for line in config:
        match = re_version.search(line)
        if match:
            version, number = match.groups()
            yield (version.upper(), number)


def pkgconfig(*packages, **kw):
    flag_map = {'-I': 'include_dirs', '-L': 'library_dirs', '-l': 'libraries'}
    for token in subprocess.check_output(['pkg-config', '--libs', '--cflags', ' '.join(packages)]).split():
        if token[:2] in flag_map:
            kw.setdefault(flag_map.get(token[:2]), []).append(token[2:])
    return kw


class PopplerExtension(Extension):
    def __init__(self, name, sources, **kwargs):
        for item, value in pkgconfig(*PACKAGES).items():
            kwargs[item] = kwargs.get(item, []) + value

        # Determine the poppler version and set the macros
        kwargs.setdefault('define_macros', [])
        version_parts = []
        for part, num in pypoppler_version():
            kwargs['define_macros'] += (("PYPOPPLER_%s_VERSION" % part, num),)
            version_parts += num

        # Process poppler.defs, this creates poppler.c
        subprocess.call(['pygobject-codegen-2.0', '--override', 'poppler.override', '--prefix', 'py_poppler', 'poppler.defs'], stdout=file('poppler.c','wb'))

        Extension.__init__(self, name, sources, **kwargs)


setup(name='poppler',
        version = '.'.join([x[1] for x in pypoppler_version()]),
        ext_modules=[
          PopplerExtension('poppler',
                            sources = ['poppler.c', 'popplermodule.c'],
                            extra_compile_args = ['-DHAVE_CONFIG_H'],
                            ),
    ])

